@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Redirect;
 {
-    $Email::Sender::Transport::Redirect::VERSION = '0.0004';
+    $Email::Sender::Transport::Redirect::VERSION = '0.005';
 }
 
 =head1 NAME
@@ -9,7 +9,7 @@ Email::Sender::Transport::Redirect - Intercept all emails and redirect them to a
 
 =head1 VERSION
 
-Version 0.0004
+Version 0.005
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,9 @@ the original recipients.
 
 =head2 redirect_address
 
-Recipient email address for redirected emails.
+Recipient email address for redirected emails. This value, which can
+be either a string or an hashref, is passed to the
+L<Email::Sender::Transport::Redirect::Recipients> constructor.
 
 =head2 redirect_headers
 
@@ -56,7 +58,8 @@ Defaults to C<X-Intercepted->.
 =cut
 
 use Moo;
-use MooX::Types::MooseLike::Base qw/ArrayRef Str/;
+use Types::Standard qw/ArrayRef Str Object/;
+use Email::Sender::Transport::Redirect::Recipients;
 
 extends 'Email::Sender::Transport::Wrapper';
 
@@ -76,6 +79,16 @@ has 'intercept_prefix' => (
                            default => 'X-Intercepted-',
                           );
 
+has recipients => (is => 'lazy',
+                        isa => Object);
+
+sub _build_recipients {
+    my $self = shift;
+    return Email::Sender::Transport::Redirect::Recipients->new($self->redirect_address);
+}
+
+
+
 =head1 METHOD MODIFIERS
 
 =head2 send_email
@@ -101,13 +114,17 @@ around send_email => sub {
             $email_copy->set_header($self->intercept_prefix . $header,
                                     @values);
         }
-
-        $email_copy->set_header($header);
+        my @replace = map { $self->recipients->replace($_) } @values;
+        $email_copy->set_header($header, @replace);
+    }
+    # if the to was set in the envelope, replace those as well
+    if ($env_copy->{to} and @{$env_copy->{to}}) {
+        $env_copy->{to} = [ map { $self->recipients->replace($_) } @{$env_copy->{to}} ]
+    }
+    # no to in the envelope? then set it
+    else {
+        $env_copy->{to} = [ $self->recipients->to ];
     }
-
-    $email_copy->set_header('To', $self->redirect_address);
-    $env_copy->{to} = [$self->redirect_address];
-
     return $self->$orig($email_copy, $env_copy, @rest);
 };
 
